pub struct NoSuchVariable {
pub position: usize,
pub name: String,
}Expand description
The input string contains a placeholder for a variable that is not in the variable map.
Fields
position: usizeThe byte offset within the input where the error occurs.
This points to the first character of the name in the input text.
name: StringThe name of the variable.