pub struct UnexpectedCharacter {
pub position: usize,
pub character: CharOrByte,
pub expected: ExpectedCharacter,
}Expand description
The input string contains an unexpected character.
Fields
position: usizeThe byte offset within the input where the error occurs.
This points to the unexpected character in the input text.
character: CharOrByteThe unexpected character.
If the unexpected character is not a valid UTF-8 sequence, this will simply hold the value of the unexpected byte.
expected: ExpectedCharacterA human readable message about what was expected instead.